@@ -6,11 +6,12 @@ from __future__ import annotations
 from typing import (
     Type,
 )
+import logging
 import requests
 
-from wechaty_puppet import UrlLinkPayload
+from wechaty_puppet import UrlLinkPayload   # type: ignore
 
-from ..config import log
+log = logging.getLogger('UrlLink')
 
 
 class UrlLink:
@@ -35,10 +36,11 @@ class UrlLink:
         """doc"""
         log.info('create url_link for %s', url)
         res = requests.get(url)
+
         payload = UrlLinkPayload(
-            title=res.content.__str__(),
-            url='https://github.com/wechaty/',
-        )
+            title=res.content.title().decode("utf-8"),
+            url=url)
+        # TODO -> get description, thumbnail_url of a website
         return UrlLink(payload)
 
     def __str__(self):
@@ -46,25 +48,44 @@ class UrlLink:
         UrlLink string format output
         :return:
         """
-        return "UrlLink<%s>" % self.payload.url
+        return 'UrlLink<%s>' % self.payload.url
 
+    @property
     def title(self) -> str:
         """
         get UrlLink title
         :return:
         """
+        if self.payload.title is None:
+            return ''
         return self.payload.title
 
-    def thumbnail_url(self):
+    @property
+    def thumbnail_url(self) -> str:
         """
         get thumbnail url
         :return:
         """
+        if self.payload.thumbnail_url is None:
+            return ''
         return self.payload.thumbnail_url
 
-    def description(self):
+    @property
+    def description(self) -> str:
         """
         get description
         :return:
         """
-        self.payload.description
+        if self.payload.description is None:
+            return ''
+        return self.payload.description
+
+    @property
+    def url(self) -> str:
+        """
+        get url
+        :return:
+        """
+        if self.payload.url is None:
+            return ''
+        return self.payload.url
